==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownLogFileTextSettingsRecordStartTimestampFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * One of the supported timestamp formats
 */
public enum class KnownLogFileTextSettingsRecordStartTimestampFormat(
    public val javaValue:
    com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat> {
    ISO_8601(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.ISO_8601),
    YYYYMMDD_HH_MM_SS(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YYYYMMDD_HH_MM_SS),
    M_D_YYYY_HH_MM_SS_AM_PM(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.M_D_YYYY_HH_MM_SS_AM_PM),
    Mon_DD_YYYY_HH_MM_SS(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.Mon_DD_YYYY_HH_MM_SS),
    YyMMdd_HH_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YyMMdd_HH_mm_ss),
    DdMMyy_HH_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.DdMMyy_HH_mm_ss),
    MMM_d_hh_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.MMM_d_hh_mm_ss),
    Dd_MMM_yyyy_HH_mm_ss_zzz(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.Dd_MMM_yyyy_HH_mm_ss_zzz),
    YyyyMMddTHH_mm_ssK(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YyyyMMddTHH_mm_ssK),
    ;

    override fun toJava():
        com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat):
            KnownLogFileTextSettingsRecordStartTimestampFormat =
            KnownLogFileTextSettingsRecordStartTimestampFormat.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownLogFileTextSettingsRecordStartTimestampFormat.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * One of the supported timestamp formats
 */
public enum class KnownLogFileTextSettingsRecordStartTimestampFormat(
    public val javaValue: com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat,
) :
    ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat> {
    ISO_8601(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.ISO_8601),
    YYYYMMDD_HH_MM_SS(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YYYYMMDD_HH_MM_SS),
    M_D_YYYY_HH_MM_SS_AM_PM(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.M_D_YYYY_HH_MM_SS_AM_PM),
    Mon_DD_YYYY_HH_MM_SS(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.Mon_DD_YYYY_HH_MM_SS),
    YyMMdd_HH_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YyMMdd_HH_mm_ss),
    DdMMyy_HH_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.DdMMyy_HH_mm_ss),
    MMM_d_hh_mm_ss(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.MMM_d_hh_mm_ss),
    Dd_MMM_yyyy_HH_mm_ss_zzz(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.Dd_MMM_yyyy_HH_mm_ss_zzz),
    YyyyMMddTHH_mm_ssK(com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat.YyyyMMddTHH_mm_ssK),
    ;

    override fun toJava(): com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownLogFileTextSettingsRecordStartTimestampFormat): KnownLogFileTextSettingsRecordStartTimestampFormat =
            KnownLogFileTextSettingsRecordStartTimestampFormat.values().first { it.javaValue == javaType }
    }
}
